@@ -26,19 +26,20 @@ import com.openexchange.admin.soap.reseller.user.soap.dataobjects.User;
  *         &lt;element name="ctx" type="{http://dataobjects.soap.reseller.admin.openexchange.com/xsd}ResellerContext" minOccurs="0"/>
  *         &lt;element name="users" type="{http://dataobjects.soap.admin.openexchange.com/xsd}User" maxOccurs="unbounded" minOccurs="0"/>
  *         &lt;element name="auth" type="{http://dataobjects.rmi.admin.openexchange.com/xsd}Credentials" minOccurs="0"/>
+ *         &lt;element name="reassign" type="Integer" minOccurs="0"/>
  *       &lt;/sequence>
  *     &lt;/restriction>
  *   &lt;/complexContent>
  * &lt;/complexType>
  * </pre>
  *
- *
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "", propOrder = {
     "ctx",
     "users",
-    "auth"
+    "auth",
+    "reassign"
 })
 @XmlRootElement(name = "deleteMultiple")
 public class DeleteMultiple {
@@ -49,6 +50,9 @@ public class DeleteMultiple {
     protected List<User> users;
     @XmlElement(nillable = true)
     protected Credentials auth;
+    @XmlElement(nillable = true)
+    protected Integer reassign;
+
 
     /**
      * Ruft den Wert der ctx-Eigenschaft ab.
@@ -127,4 +131,12 @@ public class DeleteMultiple {
         this.auth = value;
     }
 
+    public Integer getReassign() {
+        return reassign;
+    }
+
+    public void setReassign(Integer reassign) {
+        this.reassign = reassign;
+    }
+
 }
